## Description

This is a simple example to show you how to configure `pysen` using `pyproject.toml`.
Please see `pyproject.toml` for more details.

You can check whether `simple_package/__init__.py` satisfies the format rules by:
```sh
$ pysen run lint
```

You can also correct errors by:
```sh
$ pysen run format
```
